
#ifndef __inclR_h__
#define __inclR_h__
/* Add this file for R interface */
#include <Rinternals.h> 
#include <R.h>
#include <R_ext/Utils.h> // to allow interruptions
#include <Rdefines.h>
#endif
